@@ -235,7 +235,7 @@ class MigrationDB:
         self.__logger.info('Выполнения отката скрипта, после ошибки миграции')
         self.__logger.debug(f'Откат скрипта: {script_name}')
         run_shell([f'mysql -u "{self.__db_user}" -p"{self.__db_password}" {self.__db_name} --html '
-                   f'-e "source {path_join(_path_to_module, "../SQL", "rollback", script_name)}"'],
+                   f'-e "source {path_join(self.__path_scripts, "rollback", script_name)}"'],
                   stderr=PIPE, shell=True)
         self.__logger.info(f'Откат выполнен')
 
@@ -283,7 +283,7 @@ class MigrationDB:
         """
         self.__check_error_migration__()
 
-        scripts = listdir(self.__path_scripts)
+        scripts = listdir(path_join(self.__path_scripts, 'migration'))
         self.__logger.debug(f'Получен список скриптов мигрирования: {str(scripts)}')
         if scripts:
             self.__check_names_migrate_scripts__(scripts)
